.. regina documentation master file, created by
   sphinx-quickstart on Wed Aug  5 16:00:21 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Regina Documentation!
======================

rezina is a scalable, distributed and easy to use system for executing python code
in parallel across multiple processors or many machines.

rezina provides a simple way to make parallel programming in python more easier,
flexible and scalable and shipped with  features like periodically schedule,
load balance, fail tolerate and dynamically add tasks .


**more docs coming soon.**


Contents:

.. toctree::
   :maxdepth: 2
   :glob:

   ./*





Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
